#
# spec file for package pam_pkcs11
#
# Copyright (c) 2012 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           pam_pkcs11
Version:        0.6.8
Release:        11.3
Url:            http://www.opensc-project.org/pam_pkcs11/
Summary:        PKCS #11 PAM Module
License:        LGPL-2.1+
Group:          Productivity/Security
Source:         %{name}-%{version}.tar.gz
Source1:        pam_pkcs11-common-auth-smartcard.pam
Source2:        baselibs.conf
Patch1:         %{name}-0.5.3-nss-conf.patch
Patch3:         %{name}-0.6.0-nss-autoconf.patch
BuildRequires:  curl-devel
BuildRequires:  flex
BuildRequires:  libxslt
BuildRequires:  mozilla-nss-devel
BuildRequires:  openldap2-devel
BuildRequires:  openssl-devel
BuildRequires:  pam-devel
BuildRequires:  pcsc-lite-devel
BuildRequires:  pkg-config
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
This Linux PAM module allows X.509 a certificate-based user
authentication. The certificate and its dedicated private key are
thereby accessed by means of an appropriate PKCS #11 module. For the
verification of the users' certificates, locally stored CA certificates
as well as online or locally accessible CRLs are used.

Additionally, the package includes pam_pkcs11-related tools: *
   pkcs11_eventmgr: Generates actions on card insert, removal, or
   time-out events

* pklogin_finder: Gets the login name that maps to a certificate

* pkcs11_inspect: Inspects the contents of a certificate

* make_hash_links: Creates hash link directories for storing CAs and
CRLs

Authors:
--------
    Mario Strasser <mast@gmx.net>
    Juan Antonio Martinez <jonsito@teleline.es>
    Antti Tapaninen <aet@cc.hut.fi>
    Timo Sirainen <tss@iki.fi>
    Ludovic Rousseau <ludovic.rousseau@free.fr>
    Andreas Jellinghaus <aj@dungeon.inka.de>
    Dominik Fischer <dom_fischer@web.de>
    Ville Skyttä <vskytta@gmail.com>

%prep
%setup -q
%patch1 -p1
%patch3 -p1
cp -a %{S:1} common-auth-smartcard
mv po/pt_br.po po/pt_BR.po
sed -i s/pt_br/pt_BR/ configure.in configure
sed -i s:/lib/:/%{_lib}/:g etc/pam_pkcs11.conf.example.in etc/pkcs11_eventmgr.conf.example

%build
%configure\
	--docdir=%{_docdir}/%{name}\
	--with-nss\
	--with-curl
make %{?jobs:-j%jobs}

%install
%makeinstall
mkdir -p $RPM_BUILD_ROOT/%{_lib}
mv $RPM_BUILD_ROOT%{_libdir}/security $RPM_BUILD_ROOT/%{_lib}
rm $RPM_BUILD_ROOT%{_libdir}/pam_pkcs11/*.*a $RPM_BUILD_ROOT/%{_lib}/security/*.*a
# Hardcoded defaults... no sysconfdir
install -dm 755 $RPM_BUILD_ROOT%{_sysconfdir}/pam_pkcs11/cacerts
install -dm 755 $RPM_BUILD_ROOT%{_sysconfdir}/pam_pkcs11/crls
cd etc
for conf in *.conf.example ; do
    install -m 644 ${conf} $RPM_BUILD_ROOT%{_sysconfdir}/pam_pkcs11/${conf%.example}
done
cd ..
mkdir -p $RPM_BUILD_ROOT%{_docdir}/%{name}
cp -a AUTHORS COPYING ChangeLog ChangeLog.svn NEWS README TODO doc/pam_pkcs11.html doc/mappers_api.html doc/api doc/README.autologin doc/README.mappers $RPM_BUILD_ROOT%{_docdir}/%{name}
mkdir -p $RPM_BUILD_ROOT%{_sysconfdir}/pam.d
cp common-auth-smartcard $RPM_BUILD_ROOT%{_sysconfdir}/pam.d/
%find_lang %{name}

%clean
rm -rf $RPM_BUILD_ROOT

%files -f  %{name}.lang
%defattr (-, root, root)
%doc %{_docdir}/%{name}
%{_bindir}/*
%{_libdir}/pam_pkcs11
/%{_lib}/security/*.so
%doc %{_mandir}/man?/*.*
%dir %{_sysconfdir}/pam_pkcs11
%dir %{_sysconfdir}/pam_pkcs11/cacerts
%dir %{_sysconfdir}/pam_pkcs11/crls
%config(noreplace) %{_sysconfdir}/pam_pkcs11/*.conf
%config(noreplace) %{_sysconfdir}/pam.d/common-auth-smartcard

%changelog
* Tue Jul 10 2012 sbrabec@suse.cz
- Updated to version 0.6.8:
  * Code cleanup.
  * Bug fixes.
  * Translation updates.
* Tue Feb 28 2012 sbrabec@suse.cz
- Change nssdb path to /etc/pki/nssdb (bnc#463469).
- Make libdir paths in pam_pkcs11.conf biarch-wise.
* Wed Jan  5 2011 sbrabec@suse.cz
- Updated to version 0.6.6:
  * Compatible with pcsc-lite-1.6.
  * New mapper API.
  * Minor fixes.
  * Translaton updates.
* Mon Feb  1 2010 jengelh@medozas.de
- package baselibs.conf
* Wed Aug  5 2009 sbrabec@suse.cz
- Updated to version 0.6.1:
  * Added functions to API.
  * Fixes from openSUSE packages upstreamed.
  * Minor fixes.
  * Translaton updates.
* Thu Jun 25 2009 sbrabec@suse.cz
- Supplement pam-32bit/pam-64bit in baselibs.conf (bnc#354164).
* Wed Oct 15 2008 sbrabec@suse.cz
- Fixed all implicit declarations.
* Tue Sep 23 2008 sbrabec@suse.cz
- Fixed uninitialized variable (bnc#351207).
* Thu Apr 10 2008 ro@suse.de
- added baselibs.conf file to build xxbit packages
  for multilib support
* Thu Sep  6 2007 jberkman@novell.com
- use the same directory for nssdb as the kerberos pkinit plugin
* Tue Jul 31 2007 sbrabec@suse.cz
- Build with NSS instead of openssl.
- Applied patches from Jacob Berkman: MS UPN OID and NSS
  configuration.
- Fixed implicit declaration.
* Thu Jul 26 2007 sbrabec@suse.cz
- Updated to version 0.6.0:
  * compiler warning fixes
  * I18N support
  * new configuration options
  * support for new environment variables
  * new tool pkcs11_setup
  * support for the NSS crypto libraries (off by default)
  * for more changes see ChangeLog.svn
* Fri May 12 2006 sbrabec@suse.cz
- New SuSE package, version 0.5.3.
